# Complete Workflow
Version: 1.0 (2025-03-25)

## PURPOSE
This workflow provides a comprehensive overview of the two-step document prompt engineering process, from initial requirement gathering through implementation and maintenance.

## TWO-STEP PROCESS OVERVIEW

The document prompt engineering process consists of two primary phases:

1. **Initial Prompt Engineering**: Focused on requirements gathering, analysis, and initial prompt creation
2. **Prompt Review**: Focused on evaluation, refinement, and optimization

This separation ensures thorough exploration followed by targeted improvement.

## DETAILED WORKFLOW

### PHASE 1: PREPARATION

#### 1.1 Project Initialization
- Define document type and purpose
- Gather sample documents
- Identify stakeholders and subject matter experts
- Establish success criteria
- Create project continuity document

#### 1.2 Requirements Analysis
- Analyze document structure and components
- Identify regulatory or compliance requirements
- Document user needs and pain points
- Map content relationships and dependencies
- Define terminology standards

#### 1.3 Environment Setup
- Create project folder structure
- Initialize artifact templates
- Establish version control approach
- Set up testing methodology
- Prepare continuity management system

### PHASE 2: INITIAL PROMPT ENGINEERING

#### 2.1 Exploratory Interview
- Conduct structured interview with Claude
- Focus on one question at a time
- Document all insights and recommendations
- Utilize extended thinking mode for complex topics
- Update continuity document with progress

#### 2.2 Document Analysis
- Analyze structural patterns
- Identify critical components
- Document domain-specific terminology
- Map content relationships
- Define document lifecycle

#### 2.3 Prompt Architecture Development
- Design context provision strategy
- Develop instruction components
- Create format specification
- Draft example blocks
- Establish guardrails and constraints

#### 2.4 Initial Prompt Creation
- Draft complete prompt using structured template
- Incorporate all key elements identified
- Ensure proper formatting and organization
- Document assumptions and design decisions
- Create Claude-optimized version if needed

#### 2.5 Preliminary Testing
- Test with sample scenarios
- Document initial performance
- Identify obvious improvement areas
- Prepare for review session
- Update continuity document

### PHASE 3: PROMPT REVIEW

#### 3.1 Performance Assessment
- Evaluate against success criteria
- Analyze output quality and consistency
- Identify strengths and weaknesses
- Document performance metrics
- Prioritize improvement areas

#### 3.2 Structural Analysis
- Evaluate context effectiveness
- Assess instruction clarity
- Review format adherence
- Analyze example utility
- Document structural insights

#### 3.3 Content Quality Evaluation
- Assess factual accuracy
- Evaluate completeness
- Review logical flow
- Check tone appropriateness
- Verify terminology consistency

#### 3.4 Optimization Strategy
- Develop targeted improvements
- Create experimental variations
- Design comparison methodology
- Define success indicators
- Document optimization approach

#### 3.5 Prompt Revision
- Implement prioritized improvements
- Create revised prompt draft
- Document changes and rationale
- Update related artifacts
- Prepare for validation testing

#### 3.6 Validation Testing
- Test with predefined scenarios
- Compare to original performance
- Document improvements
- Identify any new issues
- Make final adjustments

### PHASE 4: IMPLEMENTATION

#### 4.1 Finalization
- Make go/no-go decision
- Finalize prompt documentation
- Create implementation guide
- Establish monitoring plan
- Update all project artifacts

#### 4.2 Deployment
- Implement in target environment
- Provide user training if needed
- Monitor initial performance
- Gather feedback
- Document deployment process

#### 4.3 Performance Monitoring
- Track key performance indicators
- Collect user feedback
- Document edge cases
- Identify optimization opportunities
- Schedule periodic reviews

### PHASE 5: MAINTENANCE

#### 5.1 Periodic Review
- Evaluate ongoing performance
- Identify changing requirements
- Update prompt as needed
- Document review findings
- Schedule next review

#### 5.2 Continuous Improvement
- Implement minor optimizations
- Test variations
- Document performance changes
- Update related artifacts
- Maintain version history

## ROLE-SPECIFIC WORKFLOWS

### FOR PROMPT ENGINEERS

1. Lead initial requirements gathering
2. Conduct exploratory interviews with Claude
3. Draft initial prompt architecture
4. Create example blocks
5. Document design decisions
6. Participate in review sessions
7. Implement technical optimizations
8. Update technical documentation

### FOR SUBJECT MATTER EXPERTS

1. Provide domain knowledge
2. Review document components for accuracy
3. Validate terminology usage
4. Assess output quality
5. Identify domain-specific edge cases
6. Help prioritize improvements
7. Review final documentation
8. Support